@@ -173,7 +173,7 @@ class ImageioVideoWriter(object):
                outfile,
                fps,
                save_gif=False,
-               hd_video=False,
+               hd_video=True,
                gif_interval=1,
                **kwargs):
     """
@@ -214,7 +214,8 @@ class ImageioVideoWriter(object):
   def write(self, image, dst_size=None, **kwargs):
     if dst_size is not None:
       w, h = self._get_size(w=image.size[0], h=image.size[1], dst_size=dst_size, for_min_edge=False)
-      image = image.resize((w, h), Image.LANCZOS)
+      if image.size != (w, h):
+        image = image.resize((w, h), Image.LANCZOS)
     img_np = np.array(image)
     self.video.append_data(img_np)
     if self.video_hd is not None:
@@ -321,6 +322,86 @@ class Testing_cv2_utils(unittest.TestCase):
     pass
 
 
+class Testing_Tools(unittest.TestCase):
+
+  def test__extract_frames(self, debug=True):
+    """
+    Usage:
+        proj_root=pi-GAN-exp
+        python tl2_lib/tl2/modelarts/scripts/copy_tool.py \
+          -s s3://bucket-7001/ZhouPeng/codes/$proj_root -d /cache/$proj_root -t copytree -b /cache/$proj_root/code.zip
+        cd /cache/$proj_root
+        cp tl2_lib/tl2/modelarts/sources/pip.conf.modelarts /root/.pip/pip.conf
+        cp tl2_lib/tl2/modelarts/sources/sources.list.modelarts /etc/apt/sources.list
+        pip install -e tl2_lib
+
+        export CUDA_VISIBLE_DEVICES=0
+        export TIME_STR=0
+        export PORT=12346
+        export PYTHONPATH=.:./piGAN_lib
+        python -c "from exp.tests.test_3D_emb import Testing_Evaluation;\
+          Testing_Evaluation().test_save_images_nerfgan_no_aug(debug=False)"
+
+    :return:
+    """
+    if 'CUDA_VISIBLE_DEVICES' not in os.environ:
+      os.environ['CUDA_VISIBLE_DEVICES'] = '1'
+    if 'TIME_STR' not in os.environ:
+      os.environ['TIME_STR'] = '0'
+    from tl2 import tl2_utils
+    from tl2.launch.launch_utils import \
+      (get_command_and_outdir, setup_outdir_and_yaml, get_append_cmd_str, start_cmd_run)
+
+    tl_opts_list = tl2_utils.parser_args_from_list(name="--tl_opts", argv_list=sys.argv, type='list')
+    tl_opts = ' '.join(tl_opts_list)
+    print(f'tl_opts:\n {tl_opts}')
+    # tl_opts = ' '.join(sys.argv[sys.argv.index('--tl_opts') + 1:]) if '--tl_opts' in sys.argv else ''
+    # print(f'tl_opts:\n {tl_opts}')
+
+    # debug = False
+
+    command, outdir = get_command_and_outdir(self, func_name=sys._getframe().f_code.co_name, file=__file__)
+    argv_str = f"""
+                --tl_config_file None
+                --tl_command None
+                --tl_outdir {outdir}
+                --tl_opts {tl_opts}
+                {"--tl_debug" if debug else ""}
+                """
+    args, cfg = setup_outdir_and_yaml(argv_str, return_cfg=True)
+
+    os.environ['PATH'] = f"{os.path.dirname(sys.executable)}:{os.environ['PATH']}"
+    os.environ['TORCH_EXTENSIONS_DIR'] = "torch_extensions"
+
+    n_gpus = len(os.environ['CUDA_VISIBLE_DEVICES'].split(','))
+    PORT = os.environ.get('PORT', 8888)
+
+    import cv2
+    from pathlib import Path
+    from tl2.launch.launch_utils import global_cfg
+    from tl2.proj.cv2 import cv2_utils
+    from tl2.proj.pil import pil_utils
+
+    # video_file = Path("datasets/videos/nerfgan/seed_8624.mp4")
+    video_file = Path("datasets/videos/nerfgan/seed_4840.mp4")
+
+    cap = cv2.VideoCapture(str(video_file))
+
+    count = 0
+    while True:
+      ret_success, frame = cap.read()
+      if not ret_success:
+        break
+      img_pil = cv2_utils.cv2_to_pil(frame, is_bgr=True)
+      if debug:
+        pil_utils.imshow_pil(img_pil)
+
+      save_path = f"{outdir}/imgdir/{video_file.stem}_{count:03d}.jpg"
+      count += 1
+      img_pil.save(save_path)
+
+    print(outdir)
+    pass
 
 
 
