@@ -343,6 +343,19 @@ def draw_rectangle_and_return_crop(image, left, upper, w, h, outline='#ff0000',
   return patch
 
 
+def pil_rectangle(image,
+                  left,
+                  upper,
+                  right,
+                  lower,
+                  outline='#ff0000',
+                  width=2):
+  draw = ImageDraw.Draw(image)
+  bbox = ((left, upper), (right, lower))
+  draw.rectangle(bbox, outline=outline, width=width)
+  return image
+
+
 class Testing_pil_utils(unittest.TestCase):
 
   def test_draw_text_on_rectangle(self, debug=True):
@@ -707,4 +720,20 @@ class Testing_pil_utils(unittest.TestCase):
 
     plt.imshow(merged_img)
     plt.show()
-    pass
\ No newline at end of file
+    pass
+
+
+def pad2square(pil_img,
+               background_color=(127, 127, 127)):
+
+  width, height = pil_img.size
+  if width == height:
+    return pil_img
+  elif width > height:
+    result = Image.new(pil_img.mode, (width, width), background_color)
+    result.paste(pil_img, (0, (width - height) // 2))
+    return result
+  else:
+    result = Image.new(pil_img.mode, (height, height), background_color)
+    result.paste(pil_img, ((height - width) // 2, 0))
+    return result
\ No newline at end of file
