@@ -16,6 +16,8 @@ from tl2.proj.logger.logger_utils import get_file_logger
 from tl2 import tl2_utils
 from tl2.proj.streamlit import st_utils
 from tl2.proj.fvcore import build_model, MODEL_REGISTRY
+from tl2.proj.cv2 import cv2_utils
+from tl2.proj.pil import pil_utils
 
 # sys.path.insert(0, f"{os.getcwd()}/DGP_lib")
 # from DGP_lib import utils
@@ -149,7 +151,7 @@ class STModel(object):
     image_list_kwargs = collections.defaultdict(dict)
     for k, v in cfg.image_list_files.items():
       data_k = k
-      image_path = st_utils.parse_image_list(image_list_file=v.image_list_file, header=data_k, )
+      image_path = st_utils.parse_image_list(image_list_file=v.image_list_file, header=data_k, show_image=False)
       image_list_kwargs[data_k]['image_path'] = image_path
 
     data_k = st_utils.radio('source', options=image_list_kwargs.keys(), index=0, sidebar=True)
@@ -158,6 +160,8 @@ class STModel(object):
     if image_input:
       image_path = pathlib.Path(image_input)
 
+    st_utils.st_show_image(image_path)
+
     img_pil = Image.open(image_path)
     st_utils.st_image(img_pil, caption=f"{img_pil.size}, {data_k}", debug=global_cfg.tl_debug, )
     st.write(image_path)
@@ -197,7 +201,10 @@ def main():
   # outdir
   kwargs = {}
   if not global_cfg.tl_debug and global_cfg.get("st_web", True):
-    saved_suffix_state = SessionState.get(saved_suffix=0)
+    # saved_suffix_state = SessionState.get(saved_suffix=0)
+    saved_suffix_state = st.session_state
+    if 'saved_suffix' not in saved_suffix_state:
+      saved_suffix_state['saved_suffix'] = 0
     saved_suffix = saved_suffix_state.saved_suffix
     kwargs.update({'saved_suffix_state': saved_suffix_state})
   else:
@@ -221,7 +228,12 @@ def main():
 
   st_model = build_model_st()
 
-  mode = st_utils.selectbox(label='mode', options=global_cfg.mode, sidebar=True)
+  if 'default_mode' in global_cfg:
+    mode = st_utils.selectbox(label='mode', options=global_cfg.mode, default_value=global_cfg.default_mode,
+                              sidebar=True)
+  else:
+    mode = st_utils.selectbox(label='mode', options=global_cfg.mode, sidebar=True)
+  
   getattr(st_model, mode)(cfg=global_cfg.get(mode, {}), **kwargs)
 
   pass
