@@ -157,35 +157,43 @@ def selectbox(label,
   if value_dict is not None:
     value_dict = dict(value_dict)
     ret = value_dict[ret]
-    st.sidebar.write(f"{label}={ret}")
+    if sidebar:
+      st.sidebar.write(f"{label}={ret}")
 
   logging.getLogger('st').info(f"{label}={ret}")
-  st.write(f"{label}={ret}")
+  # st.write(f"{label}={ret}")
   print(f"{label}={ret}")
   return ret
 
 def selectbox_v1(label,
                  options_dict,
                  default_key,
-                 sidebar=False):
+                 sidebar=False,
+                 ret_key_value=False,
+                 verbose=True):
   options_dict = dict(options_dict)
 
   options_keys = list(options_dict.keys())
   index = options_keys.index(default_key)
   if sidebar:
-    ret = st.sidebar.selectbox(label=label, options=options_keys, index=index)
+    ret_key = st.sidebar.selectbox(label=label, options=options_keys, index=index)
   else:
-    ret = st.selectbox(label=label, options=options_keys, index=index)
+    ret_key = st.selectbox(label=label, options=options_keys, index=index)
 
-  ret = options_dict[ret]
+  ret = options_dict[ret_key]
 
   logging.getLogger('st').info(f"{label}={ret}")
-  if sidebar:
-    st.sidebar.write(f"{ret}")
-  else:
-    st.write(f"{label}={ret}")
+  if verbose:
+    if sidebar:
+      st.sidebar.write(f"{ret_key}={ret}")
+    else:
+      st.write(f"{label}={ret}")
   print(f"{label}={ret}")
-  return ret
+
+  if ret_key_value:
+    return ret_key, ret
+  else:
+    return ret
 
 def number_input(label,
                  value,
@@ -268,6 +276,12 @@ def read_image_list_and_show_in_st(image_list_file,
   return all_image_list
 
 
+def st_show_image(image_path):
+  image_pil = Image.open(image_path)
+  st.image(image_pil, caption=f"{image_path.name, image_pil.size}", width=256)
+  st.write(f"{image_path}")
+  pass
+
 def parse_image_list(image_list_file,
                      header='selected index',
                      columns=['path', ],
@@ -283,9 +297,7 @@ def parse_image_list(image_list_file,
   image_path = Path(image_path)
 
   if show_image:
-    image_pil = Image.open(image_path)
-    st.image(image_pil, caption=f"{image_path.name, image_pil.size}", width=256)
-    st.write(f"{image_path}")
+    st_show_image(image_path)
   return image_path
 
 
