@@ -24,6 +24,36 @@ import tempfile
 import pickle
 
 
+def int2bitstring(number):
+  """
+  3 -> '11'
+
+  Args:
+      number ([type]): [description]
+
+  Returns:
+      [type]: [description]
+  """
+  return f"{number:b}"
+
+def bitstring2int(bit_string):
+  """
+  '11' -> 3
+
+  3 ^ 3 = 0
+  3 & 3 = 3
+  3 << 1 = 6
+
+  Args:
+      bit_string ([type]): [description]
+
+  Returns:
+      [type]: [description]
+  """
+  bit_int = int(bit_string, 2)
+  return bit_int
+
+
 def pickle_dump(saved_path,
                 data):
 
@@ -33,6 +63,16 @@ def pickle_dump(saved_path,
   # with open(saved_path, 'rb') as f:
   #   data = pickle.load(f)
 
+def load_pickle_file(pkl_path):
+  with open(pkl_path, 'rb') as f:
+    data = pickle.load(f, encoding='latin1')
+  return data
+
+def write_pickle_file(pkl_path,
+                      data_dict):
+  with open(pkl_path, 'wb') as fp:
+    pickle.dump(data_dict, fp, protocol=2)
+
 
 def get_tempfile():
   """
@@ -63,8 +103,26 @@ class TL_tqdm(object):
 
     if start > 0:
       self.pbar.update(start)
+
+    # self.pbar_range = range(start, total)
+    self.start = start
+    self.total = total
+    self._count = start - 1
     pass
 
+  def __iter__(self):
+    self._count = self.start - 1
+    self.pbar.reset()
+    return self
+
+  def __next__(self):
+    self._count += 1
+    if self._count < self.total:
+      self.update(1)
+      return self._count
+    else:
+      raise StopIteration
+
   def __del__(self):
     self.pbar_io.close()
     pass
@@ -82,16 +140,35 @@ def os_system(command):
   pass
 
 
-def get_class_repr(self):
+def get_class_repr(self, prefix=''):
   """
   self.repr_str = tl2_utils.dict2string()
+  self.module_name_list = []
 
   :param self:
   :return:
   """
-  repr_str = f"{self.__class__.__name__}({self.repr_str})"
+  repr_str = f"{prefix}.{self.__class__.__name__}({self.repr_str})"
   return repr_str
 
+def print_repr(self):
+  """
+  self.module_name_list = []
+
+  :param self:
+  :return:
+  """
+  from tl2.proj.pytorch import torch_utils
+
+  models_dict = {}
+  for name in self.module_name_list:
+    models_dict[name] = attrgetter_default(object=self, attr=name)
+  models_dict['All'] = self
+  logger = logging.getLogger('tl')
+  torch_utils.print_number_params(models_dict=models_dict, logger=logger)
+  logger.info(self)
+  pass
+
 def to_dict_recursive(dict_input):
 
   ret_dict = collections.OrderedDict()
@@ -249,12 +326,12 @@ def time_us2string(time_start, repeat_times=None):
   time_end = time.perf_counter()
   elapsed = time_end - time_start
 
-  time_str = f"all: {elapsed} s"
+  time_str = f"all (repeat={repeat_times}): {elapsed} s"
 
   if repeat_times is None:
     repeat_times = 1.
 
-  time_str += f", every (repeat={repeat_times}): {elapsed/repeat_times}"
+  time_str += f", all/repeat: {elapsed/repeat_times} s"
 
   time_str += f", fps: {1. / (elapsed / repeat_times)}"
 
@@ -416,7 +493,7 @@ def check_image_list_validity(image_file):
 
 def read_image_list_from_files(image_list_file,
                                compress=False,
-                               ext=('*.jpg', '*.png')):
+                               ext=('*.jpg', '*.png', '*.jpeg')):
   """
 
   :param image_list_file: [image_list.txt, ] or [image_dir, ]
@@ -491,7 +568,7 @@ def json_dump(obj_dict, file_path):
 def parser_args_from_list(name, argv_list, type='list'):
   """
 
-  :param name: --tl_opts
+  :param name: '--tl_opts'
   :param argv_list:
   :return:
   """
@@ -503,10 +580,20 @@ def parser_args_from_list(name, argv_list, type='list'):
     parser.add_argument(name)
   args, _ = parser.parse_known_args(args=argv_list)
 
-  value = getattr(args, name.strip('-'))
+  value = getattr(args, name.strip('-').replace('-', '_'))
   print(f"{name}={value}")
   return value
 
 
+def is_debugging():
+  import sys
+  gettrace = getattr(sys, 'gettrace', None)
+
+  if gettrace is None:
+    assert 0, ('No sys.gettrace')
+  elif gettrace():
+    return True
+  else:
+    return False
 
 
